AsOut

Trait AsOut 

pub unsafe trait AsOut<T: ?Sized> {
    // Required method
    fn as_out(&mut self) -> Out<'_, T>;
}
Extension trait for converting a mutable reference to an out reference.

Safety

This trait can be trusted to be implemented correctly for all types.

Required Methods

fn as_out(&mut self) -> Out<'_, T>

Returns an out reference to self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> AsOut<T> for MaybeUninit<T>

Source

fn as_out(&mut self) -> Out<'_, T>

Source

impl<T> AsOut<[T]> for [MaybeUninit<T>]

Source

fn as_out(&mut self) -> Out<'_, [T]>

Source

impl<T> AsOut<[T]> for [T]
where T: Copy,

Source

fn as_out(&mut self) -> Out<'_, [T]>

Implementors

Source

impl<T> AsOut<T> for T
where T: Copy,